[![Documentation Status](https://readthedocs.org/projects/skingrabber/badge/?version=latest)](https://skingrabber.readthedocs.io/en/latest/?badge=latest)

# SkinGrabber
A Python API wrapper for Minecraft skins and UUID's

Current Version = `0.1.4`

## Documentation

Documentation is available here: https://skingrabber.readthedocs.io/

## Installation

To install skingrabber, do:

`pip install skingrabber` or `pip3 install skingrabber`

## Examples

Some examples are available in the [examples folder](https://github.com/MakufonSkifto/skingrabber/tree/master/examples)

For more detailed explanations and functions, visit [the docs](https://skingrabber.readthedocs.io/)
